*** ("###################################################################") 

*** "LIQUIDITY COINSURANCE AND BANK CAPITAL"
*** Fabio Castiglionesi - Fabio Feriozzi - Gyngyi Lrnth - Loriana Pelizzon

*** STATISTICS, PCA AND REGRESSIONS

*** Code developed by Mario Bellia (bellia@unive.it)

*** ("###################################################################") 


*PS: Suffix "_W" stands for WINSORIZED


use "/Research/SDI-FDIC Data/Files for JCMB/2_SDI_DATA.dta"


*** ("####################################") 
*** Table 2  Summary statistics  ****
*** ("####################################") 
tabstat Capital Interbank Fed_Funds_Repos  Deposits_Fed LLP Liquidity Loans Deposits ROA Size TA if closdate>=12873 & closdate<=17347,stats(count mean  sd min max p5 median p95) columns(statistics)



*** ("####################################") 
*** Table 4  Bank capital and interbank activity: Panel regressions****
*** ("####################################") 


xtreg Capital_W Interbank_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 

xtreg Capital_W Interbank_W Fed_Funds_Repos_W  Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 


*** ("####################################") 
*** Table 5  Bank capital and interbank activity: Cross-sectional regressions
*** ("####################################") 

gen anni=1995
forvalues anni= 1995/2012{
display("#####################################################")
display( anni ) 
display("Q1")
regress Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W  if year==anni&quarter==1, cluster(idrssd)
display("#####################################################") 
display( anni ) 
display("Q2")
regress Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W  if year==anni&quarter==2, cluster(idrssd) 
display("#####################################################")
display( anni ) 
display("Q3")
regress Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W  if year==anni&quarter==3, cluster(idrssd)  
display("#####################################################")
display( anni ) 
display("Q4")
regress Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W if year==anni&quarter==4, cluster(idrssd)  

replace anni=anni+1
}
drop anni


*** ("####################################") 
*** Table 6  Bank capital and interbank activity: Extended sample and crisis period
*** ("####################################") 

xtreg Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1992 dummy1993 dummy1994 dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy2008 dummy2009 dummy2010 dummy2011 dummy2012 dummy1q dummy2q dummy3q dummy4q,fe vce(cluster idrssd) 

*only post crisis
xtreg Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1992 dummy1993 dummy1994 dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy2008 dummy2009 dummy2010 dummy2011 dummy2012 dummy1q dummy2q dummy3q dummy4q if closdate>17347,fe vce(cluster idrssd) 


*** ("####################################") 
*** Table 7  Bank capital and interbank activity: Net lender and net borrower
*** ("####################################") 

*Net Lender 
*dummyIPos=(I>0)
xtreg Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007  dummy1q dummy2q dummy3q dummy4q if closdate>=12873 & closdate<=17347 & dummyIPos==1,fe vce(cluster idrssd) 

*Net Borrower 
*dummyINeg=(I<0)
xtreg Capital_W Interbank_W Fed_Funds_Repos_W Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if closdate>=12873 & closdate<=17347 & dummyINeg==1,fe vce(cluster idrssd) 


*** ("####################################") 
*** Table 8  Bank capital and interbank activity: Bank size
*** ("####################################") 

* Breaking down the sample of size category
* <$300M, $300M-$1B, $1B-$50B, over $50B and estimate separately

gen dummy_300=(TA<300000)
gen dummy_300e1B=(TA>=300000)&(TA<1000000)
gen dummy_1Be50B=(TA>=1000000)&(TA<50000000)
gen dummy_50B=(TA>=50000000)


*** ("TA< 300'000  ")
xtreg  Capital_W Interbank_W Fed_Funds_Repos_W  Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if dummy_300==1 & closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 

*** ("(TA>=300'000)&(TA<1'000'000) ")
xtreg  Capital_W Interbank_W Fed_Funds_Repos_W  Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if dummy_300e1B==1 & closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 

*** ("(TA>=1'000'000)&(TA<50'000'000) ")
xtreg  Capital_W Interbank_W Fed_Funds_Repos_W  Deposits_Fed_W LLP_W Liquidity_W Loans_W Deposits_W ROA_W Size_W dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q  if dummy_1Be50B==1 & closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 

*** (" TA>=50'000'000 ")
xtreg  Capital Interbank Fed_Funds_Repos  Deposits_Fed LLP Liquidity Loans Deposits ROA Size dummy1995 dummy1996 dummy1997 dummy1998 dummy1999 dummy2000 dummy2001 dummy2002 dummy2003 dummy2004 dummy2005 dummy2006 dummy2007 dummy1q dummy2q dummy3q dummy4q if dummy_50B==1 & closdate>=12873 & closdate<=17347,fe vce(cluster idrssd) 



*** ("####################################") 
*** Table B2  Correlation matrix
*** ("####################################") 

corr  Capital Interbank Fed_Funds_Repos  Deposits_Fed LLP Liquidity Loans Deposits ROA Size if closdate>=12873 & closdate<=17347





